"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var node_fetch_1 = __importDefault(require("node-fetch"));
/*
* Function to fetch list of cities
*/
exports.fetchCities = function (cityName, print, strict) {
    if (print === void 0) { print = true; }
    if (strict === void 0) { strict = false; }
    return new Promise(function (resolve, reject) {
        // Fetch list
        node_fetch_1.default('https://in.bookmyshow.com/serv/getData/?cmd=GETREGIONS')
            .then(function (res) { return res.text(); })
            // Clean response
            .then(function (res) {
            res = res.replace('var regionlst=', '');
            res = res.replace(';var regionalias=', '&&');
            res = res.replace(';var statelist=[];var subregionlist=', '&&');
            var arr = res.split('&&');
            return arr;
        })
            // Convert to JSON
            .then(function (res) {
            return res.map(function (r) { return JSON.parse(r); });
        })
            // Extract regions
            .then(function (res) {
            var regionList = res[0];
            var regionCodes = Object.keys(regionList);
            var regions = regionCodes.map(function (code) { return regionList[code][0]; });
            return regions;
        })
            .then(function (regions) {
            var cities = regions.filter(function (r) {
                if (strict) {
                    if (r.alias === cityName || r.code === cityName || r.name === cityName)
                        return true;
                    else
                        return false;
                }
                else {
                    if (r.alias.search(cityName) > -1 || r.code.search(cityName) > -1 || r.name.search(cityName) > -1)
                        return true;
                    else
                        return false;
                }
            });
            if (cities && print) {
                console.table(cities);
                console.log('Use the exact code, name, alias in place of `city` while searching for movies.');
            }
            else if (!cities) {
                throw new Error('Oops! City not found');
            }
            return cities;
        })
            // Resolve
            .then(resolve)
            // Reject
            .catch(reject);
    });
};
