"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var node_fetch_1 = __importDefault(require("node-fetch"));
var lib_1 = require("../lib");
var table_1 = require("table");
/*
* Function to fetch list of Movies
*/
exports.fetchAllMovies = function (city) {
    return new Promise(function (resolve, reject) {
        // Get region code
        lib_1.fetchCities(city, false, true)
            .then(function (regions) {
            if (!regions.length)
                throw new Error('City not found. Please use `bookmyshow city [cityName]` to find your city');
            var region = regions[0];
            var regionCode = region.code;
            return regionCode;
        })
            // Fetch movies
            .then(function (regionCode) {
            return node_fetch_1.default('https://in.bookmyshow.com/serv/getData?cmd=QUICKBOOK&type=MT', {
                method: 'GET',
                headers: {
                    'Cookie': 'Rgn=%7CCode%3D' + regionCode
                }
            });
        })
            // Extract JSON
            .then(function (res) { return res.json(); })
            // Strip needed info
            .then(function (eventResponse) {
            var events = eventResponse.moviesData.BookMyShow.arrEvents;
            var movies = events.map(function (event) {
                return [
                    event.ChildEvents[0].EventCode,
                    event.ChildEvents[0].EventName,
                    event.ChildEvents[0].EventGenre,
                    event.ChildEvents[0].EventLanguage,
                ];
            });
            return [['Code', 'Name', 'Genre', 'Language']].concat(movies);
        })
            // Print table
            .then(function (movies) {
            console.log(table_1.table(movies));
            return movies;
        })
            // Resolve
            .then(resolve)
            // Reject
            .catch(reject);
    });
};
/*
* Function to fetch single movie
*/
exports.fetchSingleMovie = function (city, movieId) {
    return new Promise(function (resolve, reject) {
        // Get region code
        lib_1.fetchCities(city, false, true)
            .then(function (regions) {
            if (!regions.length)
                throw new Error('City not found. Please use `bookmyshow city [cityName]` to find your city');
            var region = regions[0];
            var regionCode = region.code;
            return regionCode;
        })
            // Make request
            .then(function (regionCode) {
            return node_fetch_1.default('https://in.bookmyshow.com/serv/getData?cmd=QUICKBOOK&type=MT', {
                method: 'GET',
                headers: {
                    'Cookie': 'Rgn=%7CCode%3D' + regionCode
                }
            });
        })
            // Extract JSON
            .then(function (res) { return res.json(); })
            // Extract important info
            .then(function (eventResponse) {
            var events = eventResponse.moviesData.BookMyShow.arrEvents;
            var movies = events.map(function (event) {
                return {
                    code: event.ChildEvents[0].EventCode,
                    name: event.ChildEvents[0].EventName,
                    synopsis: event.ChildEvents[0].EventSynopsis,
                    duration: event.ChildEvents[0].EventDuration,
                    showDate: event.ChildEvents[0].EventDate,
                    genre: event.ChildEvents[0].EventGenre,
                    trailerUrl: event.ChildEvents[0].EventTrailerURL,
                    language: event.ChildEvents[0].EventLanguage,
                    status: event.ChildEvents[0].EventStatus,
                    bookmyshowUrl: "https://in.bookmyshow.com/" + event.ChildEvents[0].RegCode + "/movies/" + event.ChildEvents[0].EventURL + "/" + event.ChildEvents[0].EventCode
                };
            });
            return movies;
        })
            // Find movie by code
            .then(function (movies) {
            var movie = movies.find(function (movie) {
                if (movie.code === movieId)
                    return true;
                else
                    return false;
            });
            if (!movie)
                throw new Error('Movie not found');
            return movie;
        })
            // Beautify and print
            .then(function (movie) {
            var config = {
                columns: {
                    1: {
                        width: 80,
                        wrapWord: true
                    }
                }
            };
            var tableArray = [
                ['Code', movie.code],
                ['Name', movie.name],
                ['Synopsis', movie.synopsis],
                ['Duration', movie.duration.toString()],
                ['Show Date', movie.showDate],
                ['Genre', movie.genre],
                ['Trailer link', movie.trailerUrl],
                ['Language', movie.language],
                ['Booking link', movie.bookmyshowUrl]
            ];
            console.log(table_1.table(tableArray, config));
            return movie;
        })
            // Resolve
            .then(resolve)
            // Reject
            .catch(reject);
    });
};
